@@ -4,19 +4,18 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -191,10 +190,15 @@ Cpp(const char *file)
 			DBG_PRINT(level, "class");
 			if ((c = nexttoken(interested, cpp_reserved_word)) == SYMBOL) {
 				strlimcpy(classname, token, sizeof(classname));
-				if (target == DEF)
-					PUT(token, lineno, sp);
-				if (peekc(0) != ';')
+				/*
+				 * Ignore forward definitions.
+				 * "class name;"
+				 */
+				if (peekc(0) != ';') {
 					startclass = 1;
+					if (target == DEF)
+						PUT(token, lineno, sp);
+				}
 			}
 			break;
 		case '{':  /* } */
@@ -339,7 +343,7 @@ Cpp(const char *file)
 					}
 				}
 				if (c == EOF && wflag)
-					warning("templete <...> isn't closed. [+%d %s].", lineno, curfile);
+					warning("template <...> isn't closed. [+%d %s].", lineno, curfile);
 			}
 			break;
 		case CPP_OPERATOR:
