@@ -1,22 +1,21 @@
 /*
- * Copyright (c) 1999, 2000, 2001
+ * Copyright (c) 1999, 2000, 2001, 2007
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,13 +29,12 @@
 #include "version.h"
 
 const char *copy = "\
-Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,\n\
-	2006, 2007 Tama Communications Corporation\n\
-GNU GLOBAL comes with NO WARRANTY, to the extent permitted by law.\n\
-You may redistribute copies of GNU GLOBAL under the terms of the\n\
-GNU General Public License. For more information about these matters,\n\
-see the files named COPYING.\n\
-See also: http://www.gnu.org/software/global/\n\
+Copyright (c) 2007 Tama Communications Corporation\n\
+License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
+This is free software: you are free to change and redistribute it.\n\
+There is NO WARRANTY, to the extent permitted by law.\n\
+This is also commercial (for-profit) software based on BOKIN model.\n\
+Please see the donation page <http://www.gnu.org/software/global/donation.html>.\n\
 ";
 /*
  * get_version: get version string.
@@ -54,11 +52,15 @@ version(const char *name, const int verbose)
 {
 	if (name == NULL)
 		name = progname;
-	if (verbose) {
+	/*
+	 * if the -q option is not specified then always verbose
+	 * according to the GNU coding standard
+	 */
+	if (qflag)
+		fprintf(stdout, "%s\n", VERSION);
+	else {
 		fprintf(stdout, "%s - %s\n", name, PACKAGE_STRING);
 		fprintf(stdout, "%s", copy);
-	} else {
-		fprintf(stdout, "%s\n", VERSION);
 	}
 	exit(0);
 }
